pygeodesy.cartesianBase.RadiusThetaPhi3Tuple

Package pygeodesy :: Module cartesianBase :: Class RadiusThetaPhi3Tuple |
[frames] | no frames]

# Class RadiusThetaPhi3Tuple

           object --+
                    |
                tuple --+
                        |
           object --+   |
                    |   |
         named._Named --+
                        |
        named._NamedTuple --+
                            |
    namedTuples._NamedTupleTo --+
                                |
                               RadiusThetaPhi3Tuple

3-Tuple `(r, theta, phi)` with radial distance `r` in `meter`, inclination `theta` (with respect to the positive z-axis) and azimuthal angle `phi` in Degrees or Radians representing a spherical, polar position.

Instance Methods
toCartesian(self, **name_Cartesian_and_kwds) Convert this RadiusThetaPhi3Tuple to a cartesian `(x, y, z)` vector. |
toDegrees(self, **name) Convert this RadiusThetaPhi3Tuple's angles to Degrees. |
toRadians(self, **name) Convert this RadiusThetaPhi3Tuple's angles to Radians. |
Inherited from `named._NamedTuple`: `__delattr__`, `__getattr__`, `__hash__`, `__repr__`, `__setattr__`, `__str__`, `dup`, `items`, `iteritems`, `iterunits`, `reUnit`, `toRepr`, `toStr`, `toUnits`, `units` Inherited from `tuple`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__rmul__`, `count`, `index` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `named._NamedTuple`: `__new__`

Properties
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### toCartesian (self, **name_Cartesian_and_kwds) |
Convert this RadiusThetaPhi3Tuple to a cartesian `(x, y, z)` vector. Arguments: `name_Cartesian_and_kwds` - Optional `name=NN`, overriding this name and optional class `Cartesian=None` and additional `Cartesian` keyword arguments. Returns: A `Cartesian(x, y, z)` instance or if no `Cartesian` keyword argument is given, a Vector3Tuple`(x, y, z)` with `x`, `y` and `z` in the same units as radius `r`, `meter` conventionally. See Also: Function rtp2xyz_.

### toDegrees (self, **name) |
Convert this RadiusThetaPhi3Tuple's angles to Degrees. Arguments: `name` - Optional `name=NN` (`str`), overriding this name. Returns: RadiusThetaPhi3Tuple`(r, theta, phi)` with `theta` and `phi` both in Degrees.

### toRadians (self, **name) |
Convert this RadiusThetaPhi3Tuple's angles to Radians. Arguments: `name` - Optional `name=NN` (`str`), overriding this name. Returns: RadiusThetaPhi3Tuple`(r, theta, phi)` with `theta` and `phi` both in Radians.